package banking;

import java.sql.Connection;

/**
 *  A simple banking Database interface.
 *
 *@author     <a href="mailto:Sara.Bouchenak@inria.fr">Sara Bouchenak</a>
 *@version    1.0 - 13/01/2004
 */
public interface Database {
	
	/**
	 * Queries the database to return the balance of 
	 * an account given its number.
	 * 
	 * @return	The account number.
	 * @throws	InconsistentDatabaseException if a problem occurs 
	 * when querying the database.
	 */
	public float query(int accountNumber)
		throws InconsistentDatabaseException;
	
	/**
	 * Updates the database to set the new amount of 
	 * an account balance given its number.
	 * 
	 * @param amount	The balance to be set
	 * @throws	InconsistentDatabaseException if a problem occurs 
	 * when querying the database.
	 */
	public void update(int accountNumber, float amount)
		throws InconsistentDatabaseException;
	
	/**
	 * Opens a database connection.
	 * 
	 * @return			A database connection
	 */
	public Connection getConnection();
	
}